@@ -14,6 +14,7 @@ from dai_python_commons import dai_error
 
 # pylint: disable=no-member
 
+
 class S3Utils:
     """
     Class provides functions to modify s3 buckets
@@ -47,7 +48,7 @@ class S3Utils:
         for item in page_iterator.search("Contents"):
             if not item:
                 break
-            to_delete.append(dict(Key=item["Key"]))
+            to_delete.append({"Key": item["Key"]})
 
         # delete the objects
         return S3Utils.delete_objects(
@@ -85,7 +86,7 @@ class S3Utils:
         start_index = 0
         while start_index < len(to_delete):
             end_index = min(len(to_delete), start_index + 1000)
-            batch_to_delete = DeleteTypeDef( Objects=to_delete[start_index:end_index] )
+            batch_to_delete = DeleteTypeDef(Objects=to_delete[start_index:end_index])
             logger.debug(f"Deleting {batch_to_delete}")
             response = boto_s3_client.delete_objects(
                 Bucket=bucket_name, Delete=batch_to_delete
@@ -222,7 +223,9 @@ class S3Utils:
             logger.error(
                 f"Unable to obtain LastModified for s3://{bucket_name}/{key}. Error info: {error_info}"
             )
-            raise Exception(error_info.get("Message", ""))
+            raise Exception(
+                error_info.get("Message", "")
+            )  # pylint:  disable=broad-exception-raised
 
         return response["LastModified"]
 
